@@ -146,9 +146,12 @@ if ($do==1) {
          "/featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
          "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
          "/featureName:IIS-DefaultDocument /featureName:IIS-DirectoryBrowsing ".
-         "/featureName:IIS-HttpErrors /featureName:IIS-HttpRedirect ".
-         "/featureName:IIS-CGI /featureName:IIS-ManagementConsole",
-         '__display__');
+         "/featureName:IIS-HttpErrors /featureName:IIS-HealthAndDiagnostics ".
+         "/featureName:IIS-HttpLogging /featureName:IIS-Performance ".
+         "/featureName:IIS-HttpCompressionStatic /featureName:IIS-Security ".
+         "/featureName:IIS-RequestFiltering /featureName:IIS-CGI ".
+         "/featureName:IIS-WebServerManagementTools ".
+         "/featureName:IIS-ManagementConsole",'__display__');
       my $appcmd="$ENV{WINDIR}/SYSTEM32/inetsrv";
       ($appcmd,$stderr)=$handle->cmd("cygpath -u $appcmd");
       my $cyglocb=$handle->cmd("cygpath -w /");
